"""Data model for starting a bulk import."""

from msgspec import Struct


class StartImportResponse(Struct, kw_only=True):
    """Response from starting a bulk import operation.

    Attributes:
        id: Unique identifier for the created import operation.
    """

    id: str
