"""Data model for cancelling a bulk import."""

from msgspec import Struct


class CancelImportResponse(Struct, kw_only=True):
    """Response from cancelling a bulk import operation.

    This is an empty response indicating success.
    """
