"""Data model for delete namespace operation."""

from msgspec import Struct


class DeleteNamespaceResponse(Struct, kw_only=True):
    """Response from deleting a namespace.

    The API returns an empty object on success.
    """
